pub struct CompletionFlags(/* private fields */);Expand description
Flags de complétion IORING_CQE_F_* (axe E, 5 flags en 6.12).
Exposés de façon typée par les méthodes de Completion
(has_more, is_notif, buffer_id, socket_has_pending_data).
Implementations
Sourceimpl CompletionFlags
impl CompletionFlags
Sourcepub const BUFFER: CompletionFlags
pub const BUFFER: CompletionFlags
IORING_CQE_F_BUFFER : un buffer fourni a été consommé (id dans les bits hauts).
Sourcepub const MORE: CompletionFlags
pub const MORE: CompletionFlags
IORING_CQE_F_MORE : d’autres complétions suivront (multishot, Temps 3d).
Sourcepub const SOCK_NONEMPTY: CompletionFlags
pub const SOCK_NONEMPTY: CompletionFlags
IORING_CQE_F_SOCK_NONEMPTY : données restantes lisibles après un recv.
Sourcepub const NOTIF: CompletionFlags
pub const NOTIF: CompletionFlags
IORING_CQE_F_NOTIF : complétion de notification zero-copy (Temps 2b).
Sourcepub const BUF_MORE: CompletionFlags
pub const BUF_MORE: CompletionFlags
IORING_CQE_F_BUF_MORE : consommation incrémentale d’un buffer (Temps 3b).
Sourceimpl CompletionFlags
impl CompletionFlags
Sourcepub const fn empty() -> CompletionFlags
pub const fn empty() -> CompletionFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> CompletionFlags
pub const fn all() -> CompletionFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<CompletionFlags>
pub const fn from_bits(bits: u32) -> Option<CompletionFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> CompletionFlags
pub const fn from_bits_truncate(bits: u32) -> CompletionFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> CompletionFlags
pub const fn from_bits_retain(bits: u32) -> CompletionFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CompletionFlags>
pub fn from_name(name: &str) -> Option<CompletionFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CompletionFlags) -> bool
pub const fn intersects(&self, other: CompletionFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: CompletionFlags) -> bool
pub const fn contains(&self, other: CompletionFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: CompletionFlags)
pub fn insert(&mut self, other: CompletionFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: CompletionFlags)
pub fn remove(&mut self, other: CompletionFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CompletionFlags)
pub fn toggle(&mut self, other: CompletionFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: CompletionFlags, value: bool)
pub fn set(&mut self, other: CompletionFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CompletionFlags) -> CompletionFlags
pub const fn intersection(self, other: CompletionFlags) -> CompletionFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: CompletionFlags) -> CompletionFlags
pub const fn union(self, other: CompletionFlags) -> CompletionFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: CompletionFlags) -> CompletionFlags
pub const fn difference(self, other: CompletionFlags) -> CompletionFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: CompletionFlags,
) -> CompletionFlags
pub const fn symmetric_difference( self, other: CompletionFlags, ) -> CompletionFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> CompletionFlags
pub const fn complement(self) -> CompletionFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl CompletionFlags
impl CompletionFlags
Sourcepub const fn iter(&self) -> Iter<CompletionFlags>
pub const fn iter(&self) -> Iter<CompletionFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CompletionFlags>
pub const fn iter_names(&self) -> IterNames<CompletionFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.