Struct UringCmdFlags
pub struct UringCmdFlags(/* private fields */);Expand description
Drapeaux de l’op IORING_OP_URING_CMD (46, Temps 2d) — IORING_URING_CMD_*.
Seul FIXED existe en kernel 6.12 (IORING_URING_CMD_MASK == FIXED).
MULTISHOT est postérieur à 6.12 → hors périmètre.
Implementations
impl UringCmdFlags
impl UringCmdFlags
pub const FIXED: UringCmdFlags
pub const FIXED: UringCmdFlags
IORING_URING_CMD_FIXED (bit 0) : la commande utilise un buffer
enregistré (index dans buf_index) comme zone de données associée.
impl UringCmdFlags
impl UringCmdFlags
pub const fn empty() -> UringCmdFlags
pub const fn empty() -> UringCmdFlags
Get a flags value with all bits unset.
pub const fn all() -> UringCmdFlags
pub const fn all() -> UringCmdFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<UringCmdFlags>
pub const fn from_bits(bits: u32) -> Option<UringCmdFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> UringCmdFlags
pub const fn from_bits_truncate(bits: u32) -> UringCmdFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> UringCmdFlags
pub const fn from_bits_retain(bits: u32) -> UringCmdFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<UringCmdFlags>
pub fn from_name(name: &str) -> Option<UringCmdFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: UringCmdFlags) -> bool
pub const fn intersects(&self, other: UringCmdFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: UringCmdFlags) -> bool
pub const fn contains(&self, other: UringCmdFlags) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: UringCmdFlags)
pub fn insert(&mut self, other: UringCmdFlags)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: UringCmdFlags)
pub fn remove(&mut self, other: UringCmdFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: UringCmdFlags)
pub fn toggle(&mut self, other: UringCmdFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: UringCmdFlags, value: bool)
pub fn set(&mut self, other: UringCmdFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: UringCmdFlags) -> UringCmdFlags
pub const fn intersection(self, other: UringCmdFlags) -> UringCmdFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: UringCmdFlags) -> UringCmdFlags
pub const fn union(self, other: UringCmdFlags) -> UringCmdFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: UringCmdFlags) -> UringCmdFlags
pub const fn difference(self, other: UringCmdFlags) -> UringCmdFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: UringCmdFlags) -> UringCmdFlags
pub const fn symmetric_difference(self, other: UringCmdFlags) -> UringCmdFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> UringCmdFlags
pub const fn complement(self) -> UringCmdFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl UringCmdFlags
impl UringCmdFlags
pub const fn iter(&self) -> Iter<UringCmdFlags>
pub const fn iter(&self) -> Iter<UringCmdFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<UringCmdFlags>
pub const fn iter_names(&self) -> IterNames<UringCmdFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.