Struct SetupFlags
pub struct SetupFlags(/* private fields */);Expand description
Flags de io_uring_setup(2) (axe A, 17 flags en 6.12).
Appliqués via IoUringBuilder. Deux flags de l’axe A ne figurent pas
ici car exposés par des méthodes du builder : CQSIZE
(with_completion_queue_entries) et ATTACH_WQ (attach_work_queue).
Implementations
impl SetupFlags
impl SetupFlags
pub const IOPOLL: SetupFlags
pub const IOPOLL: SetupFlags
IORING_SETUP_IOPOLL : polling I/O (stockage O_DIRECT).
pub const SQPOLL: SetupFlags
pub const SQPOLL: SetupFlags
IORING_SETUP_SQPOLL : thread kernel de poll de la SQ (Temps 3e).
pub const SQ_AFF: SetupFlags
pub const SQ_AFF: SetupFlags
IORING_SETUP_SQ_AFF : affinité CPU du thread SQPOLL.
pub const CLAMP: SetupFlags
pub const CLAMP: SetupFlags
IORING_SETUP_CLAMP : borne entries aux limites kernel.
pub const R_DISABLED: SetupFlags
pub const R_DISABLED: SetupFlags
IORING_SETUP_R_DISABLED : ring créé désactivé (primitive sandbox, Temps 3f).
pub const SUBMIT_ALL: SetupFlags
pub const SUBMIT_ALL: SetupFlags
IORING_SETUP_SUBMIT_ALL : ne pas s’arrêter à la première erreur de soumission.
pub const COOP_TASKRUN: SetupFlags
pub const COOP_TASKRUN: SetupFlags
IORING_SETUP_COOP_TASKRUN : task-work coopératif (moins d’IPI).
pub const TASKRUN_FLAG: SetupFlags
pub const TASKRUN_FLAG: SetupFlags
IORING_SETUP_TASKRUN_FLAG : signale le task-work en attente via un flag d’anneau.
pub const SQE128: SetupFlags
pub const SQE128: SetupFlags
IORING_SETUP_SQE128 : SQE de 128 octets (requis pour URING_CMD large).
pub const CQE32: SetupFlags
pub const CQE32: SetupFlags
IORING_SETUP_CQE32 : CQE de 32 octets (complétions étendues).
pub const SINGLE_ISSUER: SetupFlags
pub const SINGLE_ISSUER: SetupFlags
IORING_SETUP_SINGLE_ISSUER : un seul thread soumetteur (recommandé Air).
pub const DEFER_TASKRUN: SetupFlags
pub const DEFER_TASKRUN: SetupFlags
IORING_SETUP_DEFER_TASKRUN : task-work différé à GETEVENTS (latence basse).
pub const NO_MMAP: SetupFlags
pub const NO_MMAP: SetupFlags
IORING_SETUP_NO_MMAP : mémoire des anneaux fournie par l’appelant (avancé, gated).
pub const REGISTERED_FD_ONLY: SetupFlags
pub const REGISTERED_FD_ONLY: SetupFlags
IORING_SETUP_REGISTERED_FD_ONLY : ring fd uniquement enregistré.
pub const NO_SQARRAY: SetupFlags
pub const NO_SQARRAY: SetupFlags
IORING_SETUP_NO_SQARRAY : supprime l’indirection du tableau d’index SQ.
impl SetupFlags
impl SetupFlags
pub const fn empty() -> SetupFlags
pub const fn empty() -> SetupFlags
Get a flags value with all bits unset.
pub const fn all() -> SetupFlags
pub const fn all() -> SetupFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<SetupFlags>
pub const fn from_bits(bits: u32) -> Option<SetupFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> SetupFlags
pub const fn from_bits_truncate(bits: u32) -> SetupFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> SetupFlags
pub const fn from_bits_retain(bits: u32) -> SetupFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<SetupFlags>
pub fn from_name(name: &str) -> Option<SetupFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: SetupFlags) -> bool
pub const fn intersects(&self, other: SetupFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: SetupFlags) -> bool
pub const fn contains(&self, other: SetupFlags) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: SetupFlags)
pub fn insert(&mut self, other: SetupFlags)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: SetupFlags)
pub fn remove(&mut self, other: SetupFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: SetupFlags)
pub fn toggle(&mut self, other: SetupFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: SetupFlags, value: bool)
pub fn set(&mut self, other: SetupFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: SetupFlags) -> SetupFlags
pub const fn intersection(self, other: SetupFlags) -> SetupFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: SetupFlags) -> SetupFlags
pub const fn union(self, other: SetupFlags) -> SetupFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: SetupFlags) -> SetupFlags
pub const fn difference(self, other: SetupFlags) -> SetupFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: SetupFlags) -> SetupFlags
pub const fn symmetric_difference(self, other: SetupFlags) -> SetupFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> SetupFlags
pub const fn complement(self) -> SetupFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl SetupFlags
impl SetupFlags
pub const fn iter(&self) -> Iter<SetupFlags>
pub const fn iter(&self) -> Iter<SetupFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<SetupFlags>
pub const fn iter_names(&self) -> IterNames<SetupFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.